==> JabberGuestSDK-iOS-10.0.2.362.zip: JabberGuestSDK-iOS-10.0.2.362/docs/api/class_c_j_guest_call.js <==
var class_c_j_guest_call =
[
    [ "CJGuestCallStateType", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6", [
      [ "GuestCallStateNotInitialized", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a1df79461691b0a94ecc20a7d2af132bd", null ],
      [ "GuestCallStateDisconnected", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6ac0c049af40c6f98f21656cf9976bcca8", null ],
      [ "GuestCallStateConnecting", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a468930722a6f7abccb0c4e79cbb7f8e0", null ],
      [ "GuestCallStateConnected", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a12891f3994c234fc90f863f55c6cad8e", null ],
      [ "GuestCallStateDisconnecting", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6abc31918187c6ba3c7d8a87bae16d8ddf", null ]
    ] ],
    [ "CJGuestMuteStateType", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cd", [
      [ "GuestMuteStateMuted", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda542351ef4a5274a84c4dca35c268b92a", null ],
      [ "GuestMuteStateUnmuting", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda833ce6539ffc381323724708b51ed169", null ],
      [ "GuestMuteStateUnmuted", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda1da9206ad9acf013d1ffbfd5a69e9c2a", null ],
      [ "GuestMuteStateMuting", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda170400165002dccc8625e8f985b2975e", null ],
      [ "CJGuestNetworkStatus_Unknown", "class_c_j_guest_call.html#a6bc63e3f3c2388c85a0289510759f7c4acf49a81a5045d46a8d7888cd4e89eb08", null ],
      [ "CJGuestNetworkStatus_Online", "class_c_j_guest_call.html#a6bc63e3f3c2388c85a0289510759f7c4aaaf30cff237764bf2b37eeda9f6769bc", null ],
      [ "CJGuestNetworkStatus_Changed", "class_c_j_guest_call.html#a6bc63e3f3c2388c85a0289510759f7c4aaf373f112b7225393047dbde9d3088b5", null ],
      [ "CJGuestNetworkStatus_Offline", "class_c_j_guest_call.html#a6bc63e3f3c2388c85a0289510759f7c4ad1288162c14ffac03705a20c12755483", null ]
    ] ],
    [ "audioSetActive:", "class_c_j_guest_call.html#ac0bbec424355df0f96ec572c79598b4a", null ],
    [ "endCall", "class_c_j_guest_call.html#af4f9cdeb182ea7d8e21cf7bd3b365ed6", null ],
    [ "init", "class_c_j_guest_call.html#a476dcf133742df4ebf6a751036f4fc84", null ],
    [ "initWithServerName:toURI:", "class_c_j_guest_call.html#adf299879b9e159174a79f8988fe2129f", null ],
    [ "muteAudioOut", "class_c_j_guest_call.html#a3de3fada66b5a028a8a1df196a700213", null ],
    [ "muteVideoOut", "class_c_j_guest_call.html#a36e1db03314c11822967ec8ec979a8a6", null ],
    [ "sendDTMF:", "class_c_j_guest_call.html#abf5ecf855883ba720855d83f6e56fc02", null ],
    [ "sendDTMFString:", "class_c_j_guest_call.html#afa77526272162cb0a0bbca2e89a1329d", null ],
    [ "startCall:", "class_c_j_guest_call.html#ae30b82ad312018e3d9ac9a09fa14dc35", null ],
    [ "startSelfView:", "class_c_j_guest_call.html#a2e83491cc5c3ce6da8bdea2231f9d554", null ],
    [ "stopSelfView", "class_c_j_guest_call.html#a236083da194cbe39cd7ff7a75157adbe", null ],
    [ "switchCamera", "class_c_j_guest_call.html#a59bb0dbb26d792ff1fc4f73b1e80b69f", null ],
    [ "unmuteAudioOut", "class_c_j_guest_call.html#a21f41a0a695b14d7b00a866d80069af4", null ],
    [ "unmuteVideoOut", "class_c_j_guest_call.html#a81e076ca33369db01e8c54859d726752", null ],
    [ "updateNetworkStatus:", "class_c_j_guest_call.html#a4a5a2c927b5fd92f3824caf5c9194083", null ],
    [ "audioInMuted", "class_c_j_guest_call.html#af55527bc83ffcfe008946b3065aefe37", null ],
    [ "audioInState", "class_c_j_guest_call.html#a12d3eb8539e63a259091e9f570c0b7cf", null ],
    [ "audioInUnmuted", "class_c_j_guest_call.html#a73f168e99ceddaf2408196285beb2cd1", null ],
    [ "audioOutMuted", "class_c_j_guest_call.html#a37c67f1e5b6764b153b87d78ce7a2682", null ],
    [ "audioOutState", "class_c_j_guest_call.html#aac7ca32ff538b5ef11f561ef0af8f74c", null ],
    [ "audioOutUnmuted", "class_c_j_guest_call.html#a0701ee843d3f4d3ba8b5c13f9769471f", null ],
    [ "audioStatistics", "class_c_j_guest_call.html#a68fe65440dbce7949ded960d60a516fe", null ],
    [ "callState", "class_c_j_guest_call.html#ae44209a5f5c35e188119fd513e0039cb", null ],
    [ "captureOrientation", "class_c_j_guest_call.html#afcdb8c26d23187af673ad21ff4c1b6c3", null ],
    [ "DEPRECATED_ATTRIBUTE", "class_c_j_guest_call.html#a0e0e80514523bcbbf78f7121bcdfaa84", null ],
    [ "htmlCallStatistics", "class_c_j_guest_call.html#a7539d25da59c2e611998dc3398340265", null ],
    [ "invalidCertDelegate", "class_c_j_guest_call.html#af84c5b7d6ca38abf6c176545c3cdcb49", null ],
    [ "remoteSize", "class_c_j_guest_call.html#a7334f2323f076df27f5670211fa9ab3e", null ],
    [ "remoteView", "class_c_j_guest_call.html#afa703adcabceb28c7d6e7c54c5442f0e", null ],
    [ "selfSize", "class_c_j_guest_call.html#a9f6e6a160c1e75e8fda94f5d2ddc1f78", null ],
    [ "selfView", "class_c_j_guest_call.html#a4077ffd42572d3d91a42feaaed23c431", null ],
    [ "sentDTMF", "class_c_j_guest_call.html#af0607f40f14bbbdcb6c43916ae3317d1", null ],
    [ "serverName", "class_c_j_guest_call.html#a0d354972cec2e8bb7c9f54c8a231b85e", null ],
    [ "toURI", "class_c_j_guest_call.html#a9935b8330cfa8ba48fa71427eeb1094a", null ],
    [ "videoInMuted", "class_c_j_guest_call.html#a90b68057f1b73748d2f4ce78fa7fdd54", null ],
    [ "videoInState", "class_c_j_guest_call.html#a86ac490077abf051f45b7a00b0c41adf", null ],
    [ "videoInUnmuted", "class_c_j_guest_call.html#a2d59f7d7b9f3439f887a96a0c098a9a5", null ],
    [ "videoOutMuted", "class_c_j_guest_call.html#a85f199ebb5dccded760b42adbfd0631a", null ],
    [ "videoOutState", "class_c_j_guest_call.html#a03dbd71114e76c2afe056e307ac740af", null ],
    [ "videoOutUnmuted", "class_c_j_guest_call.html#aef3a1b4fd543c91e909ecc41b85b1ae0", null ],
    [ "videoStatistics", "class_c_j_guest_call.html#a8aea7a0b021c08db807d869cb82b6767", null ]
];

==> JabberGuestSDK-iOS-10.6.1.837.zip: JabberGuestSDK-iOS-10.6.1.837/docs/api/class_c_j_guest_call.js <==
var class_c_j_guest_call =
[
    [ "CJGuestCallStateType", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6", [
      [ "GuestCallStateNotInitialized", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a1df79461691b0a94ecc20a7d2af132bd", null ],
      [ "GuestCallStateDisconnected", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6ac0c049af40c6f98f21656cf9976bcca8", null ],
      [ "GuestCallStateConnecting", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a468930722a6f7abccb0c4e79cbb7f8e0", null ],
      [ "GuestCallStateConnected", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6a12891f3994c234fc90f863f55c6cad8e", null ],
      [ "GuestCallStateDisconnecting", "class_c_j_guest_call.html#ad252476a4c03ee8c35f643e89be698f6abc31918187c6ba3c7d8a87bae16d8ddf", null ]
    ] ],
    [ "CJGuestMuteStateType", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cd", [
      [ "GuestMuteStateMuted", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda542351ef4a5274a84c4dca35c268b92a", null ],
      [ "GuestMuteStateUnmuting", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda833ce6539ffc381323724708b51ed169", null ],
      [ "GuestMuteStateUnmuted", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda1da9206ad9acf013d1ffbfd5a69e9c2a", null ],
      [ "GuestMuteStateMuting", "class_c_j_guest_call.html#a02c957ccbf1cab5d9c550242681e70cda170400165002dccc8625e8f985b2975e", null ]
    ] ],
    [ "audioSetActive:", "class_c_j_guest_call.html#ac0bbec424355df0f96ec572c79598b4a", null ],
    [ "endCall", "class_c_j_guest_call.html#af4f9cdeb182ea7d8e21cf7bd3b365ed6", null ],
    [ "init", "class_c_j_guest_call.html#a476dcf133742df4ebf6a751036f4fc84", null ],
    [ "initWithServerName:toURI:", "class_c_j_guest_call.html#adf299879b9e159174a79f8988fe2129f", null ],
    [ "muteAudioOut", "class_c_j_guest_call.html#a3de3fada66b5a028a8a1df196a700213", null ],
    [ "muteVideoOut", "class_c_j_guest_call.html#a36e1db03314c11822967ec8ec979a8a6", null ],
    [ "sendDTMF:", "class_c_j_guest_call.html#abf5ecf855883ba720855d83f6e56fc02", null ],
    [ "sendDTMFString:", "class_c_j_guest_call.html#afa77526272162cb0a0bbca2e89a1329d", null ],
    [ "startCall:", "class_c_j_guest_call.html#ae30b82ad312018e3d9ac9a09fa14dc35", null ],
    [ "startSelfView:", "class_c_j_guest_call.html#a2e83491cc5c3ce6da8bdea2231f9d554", null ],
    [ "stopSelfView", "class_c_j_guest_call.html#a236083da194cbe39cd7ff7a75157adbe", null ],
    [ "switchCamera", "class_c_j_guest_call.html#a59bb0dbb26d792ff1fc4f73b1e80b69f", null ],
    [ "unmuteAudioOut", "class_c_j_guest_call.html#a21f41a0a695b14d7b00a866d80069af4", null ],
    [ "unmuteVideoOut", "class_c_j_guest_call.html#a81e076ca33369db01e8c54859d726752", null ],
    [ "updateNetworkStatus:", "class_c_j_guest_call.html#a4a5a2c927b5fd92f3824caf5c9194083", null ],
    [ "audioInMuted", "class_c_j_guest_call.html#af55527bc83ffcfe008946b3065aefe37", null ],
    [ "audioInState", "class_c_j_guest_call.html#a12d3eb8539e63a259091e9f570c0b7cf", null ],
    [ "audioInUnmuted", "class_c_j_guest_call.html#a73f168e99ceddaf2408196285beb2cd1", null ],
    [ "audioOutMuted", "class_c_j_guest_call.html#a37c67f1e5b6764b153b87d78ce7a2682", null ],
    [ "audioOutState", "class_c_j_guest_call.html#aac7ca32ff538b5ef11f561ef0af8f74c", null ],
    [ "audioOutUnmuted", "class_c_j_guest_call.html#a0701ee843d3f4d3ba8b5c13f9769471f", null ],
    [ "audioStatistics", "class_c_j_guest_call.html#a68fe65440dbce7949ded960d60a516fe", null ],
    [ "callState", "class_c_j_guest_call.html#ae44209a5f5c35e188119fd513e0039cb", null ],
    [ "captureOrientation", "class_c_j_guest_call.html#afcdb8c26d23187af673ad21ff4c1b6c3", null ],
    [ "DEPRECATED_ATTRIBUTE", "class_c_j_guest_call.html#a0e0e80514523bcbbf78f7121bcdfaa84", null ],
    [ "htmlCallStatistics", "class_c_j_guest_call.html#a7539d25da59c2e611998dc3398340265", null ],
    [ "invalidCertDelegate", "class_c_j_guest_call.html#af84c5b7d6ca38abf6c176545c3cdcb49", null ],
    [ "remotePresoActive", "class_c_j_guest_call.html#a48097114d1dcc96bcaa0bd007a98dc70", null ],
    [ "remotePresoSize", "class_c_j_guest_call.html#a8c2bd5d0d91f7c449c1b55336811e523", null ],
    [ "remotePresoStarted", "class_c_j_guest_call.html#a00801267c0c6a9df1ad76b890e35669f", null ],
    [ "remotePresoView", "class_c_j_guest_call.html#aade9cb683bc21eac3c2cdb3de8459c36", null ],
    [ "remoteSize", "class_c_j_guest_call.html#a7334f2323f076df27f5670211fa9ab3e", null ],
    [ "remoteView", "class_c_j_guest_call.html#afa703adcabceb28c7d6e7c54c5442f0e", null ],
    [ "selfSize", "class_c_j_guest_call.html#a9f6e6a160c1e75e8fda94f5d2ddc1f78", null ],
    [ "selfView", "class_c_j_guest_call.html#a4077ffd42572d3d91a42feaaed23c431", null ],
    [ "sentDTMF", "class_c_j_guest_call.html#af0607f40f14bbbdcb6c43916ae3317d1", null ],
    [ "serverName", "class_c_j_guest_call.html#a0d354972cec2e8bb7c9f54c8a231b85e", null ],
    [ "toURI", "class_c_j_guest_call.html#a9935b8330cfa8ba48fa71427eeb1094a", null ],
    [ "videoInMuted", "class_c_j_guest_call.html#a90b68057f1b73748d2f4ce78fa7fdd54", null ],
    [ "videoInState", "class_c_j_guest_call.html#a86ac490077abf051f45b7a00b0c41adf", null ],
    [ "videoInUnmuted", "class_c_j_guest_call.html#a2d59f7d7b9f3439f887a96a0c098a9a5", null ],
    [ "videoOutMuted", "class_c_j_guest_call.html#a85f199ebb5dccded760b42adbfd0631a", null ],
    [ "videoOutState", "class_c_j_guest_call.html#a03dbd71114e76c2afe056e307ac740af", null ],
    [ "videoOutUnmuted", "class_c_j_guest_call.html#aef3a1b4fd543c91e909ecc41b85b1ae0", null ],
    [ "videoStatistics", "class_c_j_guest_call.html#a8aea7a0b021c08db807d869cb82b6767", null ]
];
